import numpy as np
from scipy import io

#from gnmf_projgrad_with_cov import running_method
#from nmf_multupd import running_method
import pyGNMF

data = io.loadmat("SimulatedProblemData_10x100.mat")
init = io.loadmat("NewInitialGuess.mat")

XMatrix = data['conc_with_error'][0]
n_samples, m_species = XMatrix.shape
Covariance = data['covariance']

GInit = init['g_init'][0][0:5]
FInit = init['f_init'][0][0:5]
#GMat, FMat, OFunc = gnmf_multupd_with_cov.running_method(XMatrix, Covariance, option = 'row_stacked',num_factors=3, convergence_type='relative', tolerance = 1e-6, max_iter = 500000)

GMat, FMat, OFunc = pyGNMF.gnmf_multupd_with_cov.running_method(XMatrix,
                                        G_init = GInit,
                                        F_init = FInit,
                                        covariance = Covariance,
                                        option = 'row_stacked',
                                        num_init = 5,
                                        num_factors=7,
                                        convergence_type='relative',
                                        tolerance = 1e-2,
                                        max_iter = 1000)

"""
GMatn, FMatn, OFuncn = nmf.running_method(XMatrix,
                                        G_init = GInit,
                                        F_init = FInit,
                                        num_init = 5,
                                        num_factors=7,
                                        convergence_type='relative',
                                        tolerance = 1e-6,
                                        max_iter = 15)
"""


#GMat, FMat, OFunc = nmf_multupd.running_method(XMatrix, num_factors=3, convergence_type='relative', tolerance = 1e-6, max_iter = 500000)



try:
    import cupy as np
    print("Using CuPy")
except ImportError as e:
    import numpy as np
    print("Using NumPy")

from scipy import io
from pyGNMF import gnmf_multiplicative_update as gmult
from pyGNMF import nmf_multiplicative_update as mult
from pyGNMF import gnmf_projected_gradient as gproj

data = io.loadmat("pyGNMF_testDataset.mat")
X_matrix = np.array(data['conc_with_error'])
covariance = np.array(data['covariance'])
G_init = np.array(data['g_init'])
F_init = np.array(data['f_init'])
GMat, FMat, OFunc = gproj.running_method(
    X_matrix,
    covariance,
    G_init = G_init[0],
    F_init = F_init[0],
    option='row_stacked',
    num_fact=7,
    num_init=1,
    alpha_init_G=1,
    alpha_init_F=1,
    max_iter=100,
    tolerance=1e-6,
    conv_typ='relative',
    conv_num=3,
)

"""
GMat, FMat, OFunc = gmult.running_method(
    X_matrix,
    covariance,
    G_init = 'random',
    F_init = 'random',
    option='row_stacked',
    num_fact=3,
    num_init=1,
    max_iter=10000,
    tolerance=1e-6,
    conv_typ='relative',
    conv_num=3,
)

GMat, FMat, OFunc = mult.running_method(
    X_matrix,
    G_init = 'random',
    F_init = 'random',
    num_fact=3,
    num_init=1,
    max_iter=100000,
    tolerance=1e-6,
    conv_typ='relative',
    conv_num=3,
)
"""
